==> apache-servicecomb-java-chassis-distribution-2.1.1-src.zip: apache-servicecomb-java-chassis-distribution-2.1.1-src/service-registry/registry-service-center/src/test/java/org/apache/servicecomb/serviceregistry/api/response/TestFindInstancesResponse.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.servicecomb.serviceregistry.api.response;

import java.util.ArrayList;
import java.util.List;

import org.apache.servicecomb.registry.api.registry.FindInstancesResponse;
import org.apache.servicecomb.registry.api.registry.MicroserviceInstance;
import org.junit.After;
import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;
import org.mockito.Mockito;

public class TestFindInstancesResponse {

  FindInstancesResponse oFindInstancesResponse = null;

  List<MicroserviceInstance> oListMicroserviceInstance = null;

  @Before
  public void setUp() throws Exception {
    oFindInstancesResponse = new FindInstancesResponse();
    oListMicroserviceInstance = new ArrayList<>();
    oListMicroserviceInstance.add(Mockito.mock(MicroserviceInstance.class));
  }

  @After
  public void tearDown() throws Exception {
    oFindInstancesResponse = null;
    oListMicroserviceInstance = null;
  }

  @Test
  public void testDefaultValues() {
    Assert.assertNull(oFindInstancesResponse.getInstances());
  }

  @Test
  public void testInitializedValues() {
    initFields(); //Initialize the Object
    Assert.assertEquals(1, oFindInstancesResponse.getInstances().size());
  }

  private void initFields() {
    oFindInstancesResponse.setInstances(oListMicroserviceInstance);
  }
}

==> apache-servicecomb-java-chassis-distribution-2.8.30-src.zip: apache-servicecomb-java-chassis-distribution-2.8.30-src/service-registry/registry-service-center/src/test/java/org/apache/servicecomb/serviceregistry/api/response/TestFindInstancesResponse.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.servicecomb.serviceregistry.api.response;

import java.util.ArrayList;
import java.util.List;

import org.apache.servicecomb.registry.api.registry.FindInstancesResponse;
import org.apache.servicecomb.registry.api.registry.MicroserviceInstance;
import org.junit.After;
import org.junit.Before;
import org.junit.Test;
import org.junit.jupiter.api.Assertions;
import org.mockito.Mockito;

public class TestFindInstancesResponse {

  FindInstancesResponse oFindInstancesResponse = null;

  List<MicroserviceInstance> oListMicroserviceInstance = null;

  @Before
  public void setUp() throws Exception {
    oFindInstancesResponse = new FindInstancesResponse();
    oListMicroserviceInstance = new ArrayList<>();
    oListMicroserviceInstance.add(Mockito.mock(MicroserviceInstance.class));
  }

  @After
  public void tearDown() throws Exception {
    oFindInstancesResponse = null;
    oListMicroserviceInstance = null;
  }

  @Test
  public void testDefaultValues() {
    Assertions.assertNull(oFindInstancesResponse.getInstances());
  }

  @Test
  public void testInitializedValues() {
    initFields(); //Initialize the Object
    Assertions.assertEquals(1, oFindInstancesResponse.getInstances().size());
  }

  private void initFields() {
    oFindInstancesResponse.setInstances(oListMicroserviceInstance);
  }
}
